.. _api:

Developer Interface
===================

.. module:: schwifty

IBAN
----

.. autoclass:: IBAN
   :members:


BIC
---

.. autoclass:: BIC
   :members:


Exceptions
----------

.. automodule:: schwifty.exceptions
   :members:
